<?php

namespace SM\Service;

use SM\Factory\CalendarioAgendamentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use SM\Service\FindService;

class CalendarioAgendamentoService
{
    protected $entityManager;
    protected $CalendarioAgendamentoFactory;
    protected $environment;
    protected $newCode;
    protected $connection;
    protected $FindService;

    public function __construct(EntityManager $entityManager, CalendarioAgendamentoFactory $CalendarioAgendamentoFactory, Environment $environment, NewCode $newCode, FindService $FindService)
    {
        $this->CalendarioAgendamentoFactory   = $CalendarioAgendamentoFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->FindService        = $FindService;
    }

    public function fct_apropagendamento_calendario()
    {
        return $this->CalendarioAgendamentoFactory->fct_apropagendamento_calendario();
    }

    public function fct_apropagendamento_cal($parametros)
    {
        $filtroCHAVE = '';
        if (isset($parametros["CHAVE"])) {
            // debugApi(['oi']);
            $parametros["CHAVE"] = $this->FindService->formatarArray($parametros["CHAVE"]);
            $filtroCHAVE = " AND FCT_APROPAGENDAMENTO.NRPARCNEGRECURSO IN (" . $parametros["CHAVE"] . ")";
        }
        
        $filtroNRSEQCONTRATO = '';
        if (isset($parametros["NRSEQCONTRATO"])) {
            $parametros["NRSEQCONTRATO"] = $this->FindService->formatarArray($parametros["NRSEQCONTRATO"]);
            $filtroNRSEQCONTRATO = " AND FCT_CONTRATO.NRSEQCONTRATO IN (" . $parametros["NRSEQCONTRATO"] . ")";
        }

        $filtroNRESTRUTURAM = '';
        if (isset($parametros["NRESTRUTURAM"])) {
            $parametros["NRESTRUTURAM"] = $this->FindService->formatarArray($parametros["NRESTRUTURAM"]);
            $filtroNRESTRUTURAM = " AND ESTRUTURAM.NRESTRUTURAM IN (" . $parametros["NRESTRUTURAM"] . ")";
        }


        $filtroDTINIAGENDAMENTO = '';
        if (isset($parametros['DTINIAGENDAMENTO'])) {
            $dataInicial = $parametros['DTINIAGENDAMENTO'][0];
            $dataFinal = array_key_exists("1", $parametros['DTINIAGENDAMENTO']) ? $parametros['DTINIAGENDAMENTO'][1] : null;

            if ($dataFinal != null) {
                $filtroDTINIAGENDAMENTO = " AND FCT_AGENDRECURSOCONT.DTINIAGENDAMENTO BETWEEN '" . $dataInicial . "' AND '" . $dataFinal . "' ";
                // debugApi([$filtroDTINIAGENDAMENTO]);
            } else {
                $data = $dataInicial;
                $filtroDTINIAGENDAMENTO = " AND FCT_AGENDRECURSOCONT.DTINIAGENDAMENTO BETWEEN '" . $data . "' AND TO_DATE('" . $data . "')+30 ";
                // debugApi([$filtroDTINIAGENDAMENTO]);
            }
        }

        $filtroDTFIMAGENDAMENTO = '';
        if (isset($parametros['DTFIMAGENDAMENTO'])) {
            $dataInicial = $parametros['DTFIMAGENDAMENTO'][0];
            $dataFinal = array_key_exists("1", $parametros['DTFIMAGENDAMENTO']) ? $parametros['DTFIMAGENDAMENTO'][1] : null;

            if ($dataFinal != null) {
                $filtroDTFIMAGENDAMENTO = " AND FCT_AGENDRECURSOCONT.DTFIMAGENDAMENTO BETWEEN '" . $dataInicial . "' AND '" . $dataFinal . "' ";
            } else {
                $data = $dataInicial;
                $filtroDTFIMAGENDAMENTO = " AND FCT_AGENDRECURSOCONT.DTFIMAGENDAMENTO BETWEEN '" . $data . "' AND TO_DATE('" . $data . "')+30 ";
            }
        }
        
        return $this->CalendarioAgendamentoFactory->fct_apropagendamento_cal($filtroCHAVE, $filtroNRSEQCONTRATO, $filtroNRESTRUTURAM, $filtroDTINIAGENDAMENTO, $filtroDTFIMAGENDAMENTO);
    } 

    public function fct_relacestruturacont_estruturam($parametros)
    {                
        $NRESTRUTURAM = null;
        if (isset($parametros["NRESTRUTURAM"])) {
            $NRESTRUTURAM = $this->FindService->formatarArrayUndescore($parametros["NRESTRUTURAM"]);
        }
    }

    public function find_parceiro()
    {
        return $this->CalendarioAgendamentoFactory->find_parceiro();
    } 

    public function fct_view_recursos()
    {
        return $this->CalendarioAgendamentoFactory->fct_view_recursos();
    } 

    public function fct_contrato_grid()
    {
        return $this->CalendarioAgendamentoFactory->fct_contrato_grid();
    }
}