import { Utilities } from '@/util/Utilities';
import {
    DateRange, Form, LoadingService, Modal, ModalService,
    SelectMultiple,
    TextInput,
} from '@zeedhi/common';
import {
    Http, IDictionary, IEventParam, Metadata,
} from '@zeedhi/core';
import { Calendar } from '@zeedhi/zd-calendar';

export class CalendarioLembretesController {
    public modalFiltrar!: Modal;

    public filtroHabilitado!: Boolean;

    public async criarModais() {
        this.modalFiltrar = await ModalService.createFromJson('calendarioLembretesContrato/modal/calendarioLembreteContrato_filtro', true);
    }

    public destruirModais() {
        ModalService.delete(this.modalFiltrar);
    }

    public abrirModalFiltrar() {
        this.modalFiltrar.show();
    }

    public fecharModalFiltrar() {
        this.modalFiltrar.hide();
    }

    public getDados({ component }: any) {
        const dataHoje = new Date();
        const dataInicial = new Date(dataHoje.getFullYear(), dataHoje.getMonth(), 1);
        const dataFinal = new Date(dataHoje.getFullYear(), dataHoje.getMonth() + 1, 0);

        this.postTarefasCalendario({ component }, dataInicial.toLocaleDateString(), dataFinal.toLocaleDateString(), null, null);
    }

    public postTarefasCalendario({ component }: IEventParam<Calendar>, dataInicial: any, dataFinal: any, descricao: any, contrato: any) {
        let calendarEvent: any = {};
        component.clearCalendarEvents();
        LoadingService.show();
        Http.post('/getCalendarioLembreteContrato', {
            PERIODOINICIAL: dataInicial,
            PERIODOFINAL: dataFinal,
            DSLEMBRETECONT: descricao,
            NRSEQCONTRATO: contrato,
        }).then((response: IDictionary) => {
            response.data.data.forEach((element: IDictionary) => {
                calendarEvent = {
                    id: element.NRLEMBRETECONT,
                    name: `${element.DSLEMBRETECONT}`,
                    description: `Referente ao Contrato: ${element.DESCRICAOCONTRATO}`,
                    start: this.formatarData(element.DTHRLEMBRETE),
                    end: this.formatarData(element.DTHRLEMBRETE),
                };
                component.addCalendarEvents([calendarEvent]);
            });
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            this.fecharModalFiltrar();
        });
    }

    public formatarData(data: any) {
        const hora = data.split(' ')[1];
        const dataAmericana = data.split(' ')[0].split('/').reverse().join('-');
        const dataFormatada = `${dataAmericana} ${hora}`;

        return dataFormatada;
    }

    public limparFiltros() {
        const calendario = Metadata.getInstance<Calendar>('calendario-lembrete');
        Metadata.getInstance<Form>('form-filtros').clearForm();
        this.getDados({ component: calendario });
        this.filtroHabilitado = false;
    }

    public filtrarCalendario() {
        this.filtroHabilitado = true;
        const periodo = Metadata.getInstance<DateRange>('dataFiltro').value;
        const contrato = Metadata.getInstance<SelectMultiple>('contratoFiltro').value;
        const descricao = Metadata.getInstance<TextInput>('descricaoFiltro').value;
        const calendario = Metadata.getInstance<Calendar>('calendario-lembrete');
        const dataInicial = periodo[0];
        const dataFinal = (periodo.length > 1) ? periodo[1] : null;
        const form = Metadata.getInstance<Form>('form-filtros');

        if (Utilities.validateForm(form)) {
            this.postTarefasCalendario({ component: calendario }, dataInicial, dataFinal, descricao, contrato);
        }
    }

    public clickEvento({ component }: any) {
        if (this.filtroHabilitado !== true) {
            const [ano, mes] = component.value.split('-');
            const dataInicial = new Date(ano, mes - 1, 1);
            const dataFinal = new Date(ano, mes, 0);
            this.postTarefasCalendario({ component }, dataInicial.toLocaleDateString(), dataFinal.toLocaleDateString(), null, null);
        }
    }
}
